==> cybop-0.15.0.tar.gz: cybop-0.15.0/src/constant/model/cyboi/log/level_name_log_cyboi_model.c <==
/*
 * Copyright (C) 1999-2013. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.15.0 2013-09-22
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef LEVEL_NAME_LOG_CYBOI_MODEL_CONSTANT_SOURCE
#define LEVEL_NAME_LOG_CYBOI_MODEL_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The error level name log cyboi model. */
static wchar_t ERROR_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY[] = {L'E', L'r', L'r', L'o', L'r'};
static wchar_t* ERROR_LEVEL_NAME_LOG_CYBOI_MODEL = ERROR_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY;
static int* ERROR_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The warning level name log cyboi model. */
static wchar_t WARNING_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY[] = {L'W', L'a', L'r', L'n', L'i', L'n', L'g'};
static wchar_t* WARNING_LEVEL_NAME_LOG_CYBOI_MODEL = WARNING_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY;
static int* WARNING_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The information level name log cyboi model. */
static wchar_t INFORMATION_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY[] = {L'I', L'n', L'f', L'o', L'r', L'm', L'a', L't', L'i', L'o', L'n'};
static wchar_t* INFORMATION_LEVEL_NAME_LOG_CYBOI_MODEL = INFORMATION_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY;
static int* INFORMATION_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The debug level name log cyboi model. */
static wchar_t DEBUG_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY[] = {L'D', L'e', L'b', L'u', L'g'};
static wchar_t* DEBUG_LEVEL_NAME_LOG_CYBOI_MODEL = DEBUG_LEVEL_NAME_LOG_CYBOI_MODEL_ARRAY;
static int* DEBUG_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* LEVEL_NAME_LOG_CYBOI_MODEL_CONSTANT_SOURCE */
#endif

==> cybop-0.16.0.tar.gz: cybop-0.16.0/src/constant/model/cyboi/log/level_name_log_cyboi_model.c <==
/*
 * Copyright (C) 1999-2014. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.16.0 2014-03-31
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef LEVEL_NAME_LOG_CYBOI_MODEL_CONSTANT_SOURCE
#define LEVEL_NAME_LOG_CYBOI_MODEL_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The error level name log cyboi model. */
static wchar_t* ERROR_LEVEL_NAME_LOG_CYBOI_MODEL = L"Error";
static int* ERROR_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The warning level name log cyboi model. */
static wchar_t* WARNING_LEVEL_NAME_LOG_CYBOI_MODEL = L"Warning";
static int* WARNING_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The information level name log cyboi model. */
static wchar_t* INFORMATION_LEVEL_NAME_LOG_CYBOI_MODEL = L"Information";
static int* INFORMATION_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The debug level name log cyboi model. */
static wchar_t* DEBUG_LEVEL_NAME_LOG_CYBOI_MODEL = L"Debug";
static int* DEBUG_LEVEL_NAME_LOG_CYBOI_MODEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* LEVEL_NAME_LOG_CYBOI_MODEL_CONSTANT_SOURCE */
#endif
